@@ -9,10 +9,8 @@ from typing import Optional, Union
 
 import numpy as np
 import pandas as pd
-import structlog
 from fastapi import HTTPException
-
-logger = structlog.get_logger(__name__)
+from loguru import logger
 
 
 def parse_datetime(
@@ -25,7 +23,7 @@ def parse_datetime(
     if datetime_string is None:
         return None
 
-    dt = pd.to_datetime(datetime_string, dayfirst=True, errors="coerce")
+    dt = pd.to_datetime(datetime_string, dayfirst=False, errors="coerce")
 
     if pd.isnull(dt):
         logger.exception("Error while parsing datetime string", input=datetime_string)
@@ -41,11 +39,7 @@ def parse_datetime(
 
         dt = None
 
-    if (
-        dt is not None
-        and (round_missing_time_up or round_to_days)
-        and time_unknown(dt, datetime_string)
-    ):
+    if dt is not None and (round_missing_time_up or round_to_days) and time_unknown(dt, datetime_string):
         if round_to_days:
             dt = dt + timedelta(days=1)
         else:
@@ -58,24 +52,15 @@ def parse_datetime(
 
 
 def time_unknown(dt: datetime, datetime_string: str):  # pragma: no cover
-    if (
-        dt.hour == 0
-        and dt.minute == 0
-        and dt.second == 0
-        and ":" not in datetime_string
-    ):
+    if dt.hour == 0 and dt.minute == 0 and dt.second == 0 and ":" not in datetime_string:
         return True
     return False
 
 
 def validate_begin_and_end(
-        start: datetime,
-        end: datetime,
-        data_start: Union[datetime, None] = None,
-        data_end: Union[datetime, None] = None
+    start: datetime, end: datetime, data_start: Union[datetime, None] = None, data_end: Union[datetime, None] = None
 ):
-    """
-    Checks the given date parameters and replaces them with default values if they aren't valid.
+    """Checks the given date parameters and replaces them with default values if they aren't valid.
     The resulting values are then returned.
     """
     if data_end is None:
@@ -90,48 +75,15 @@ def validate_begin_and_end(
         end = data_end
 
     if start >= data_end:
-        raise HTTPException(422, f"Invalid [start] value [{start}]: value lies after last available moment for model "
-                                 f"({data_end})")
+        raise HTTPException(
+            422, f"Invalid [start] value [{start}]: value lies after last available moment for model ({data_end})"
+        )
     if data_start is not None and end <= data_start:
-        raise HTTPException(422, f"Invalid [end] value [{end}]: value lies before first available moment for model "
-                                 f"({data_start})")
+        raise HTTPException(
+            422, f"Invalid [end] value [{end}]: value lies before first available moment for model ({data_start})"
+        )
 
     if end < start:
         raise HTTPException(422, f"Invalid [start] and [end] values: [end]({end}) lies before [start]({start})")
 
     return start, end
-
-"""
-def validate_begin_and_end(
-    start: datetime,
-    end: datetime,
-    data_start: datetime = None,
-    data_end: datetime = None,
-):
-    if data_end is None:
-        data_end = (
-            datetime.utcnow()
-        )  # Even predictions are made in the past, so no end time can lie in the future.
-
-    # Ending time needs to be filled and is at most the repo ending time
-    if end is None or end > data_end:
-        end = data_end
-
-    # Ending time needs to lie after the repo starting time as well!
-    if data_start is not None and end <= data_start:
-        end = data_start + timedelta(
-            days=7
-        )  # Set to a default of 7 days after the repo starting time
-
-    # Starting time needs to be filled and has to lie before the ending time
-    if start is None or start >= end:
-        start = end - timedelta(
-            days=7
-        )  # Set to a default of 7 days before the ending time
-
-    # Starting time needs to lie at least at the repo starting time if one is given
-    if data_start is not None and start < data_start:
-        start = data_start
-
-    return start, end
-"""
\ No newline at end of file
