@@ -4,7 +4,9 @@
 #  SPDX-FileCopyrightText: 2019-2022 Alliander N.V.
 #  SPDX-License-Identifier: MPL-2.0
 
-from weather_provider_api.routers.weather.sources.cds.client.era5sl_repository import ERA5SLRepository
+from weather_provider_api.routers.weather.sources.cds.client.era5sl_repository import (
+    ERA5SLRepository,
+)
 
 
 def main():
